==> compass-service-0.1.102-sources.jar: com/xforceplus/compass/controller/MiroNoCoopSettlementController.java <==
package com.xforceplus.compass.controller;


import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.GetMapping;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.xforceplus.ultraman.bocp.gen.plugins.XfPage;
import org.springframework.web.bind.annotation.*;
import org.springframework.beans.factory.annotation.Autowired;
import com.xforceplus.ultraman.bocp.gen.api.XfR;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.xforceplus.compass.entity.MiroNoCoopSettlement;
import com.xforceplus.compass.service.IMiroNoCoopSettlementService;
import lombok.AllArgsConstructor;
import com.xforceplus.ultraman.bocp.gen.util.ObjectCopyUtils;
import com.xforceplus.ultraman.bocp.gen.sql.pojo.ConditionQueryRequest;
import java.util.HashMap;
import java.util.Map;
import org.springframework.stereotype.Controller;
/**
 * ${table.comment}前端控制器
 *
 * @author ultraman
 * @date 2022-08-08
 */
@RestController
public class MiroNoCoopSettlementController {

  @Autowired
  private IMiroNoCoopSettlementService miroNoCoopSettlementServiceImpl;


  /**
   * 查询所有-分页模式
   * @param page 分页对象
   * @param miroNoCoopSettlement ${table.comment}
   * @return
   */
  @GetMapping("/mironocoopsettlements" )
  public XfR getMiroNoCoopSettlements(XfPage page, MiroNoCoopSettlement miroNoCoopSettlement) {
    return XfR.ok(miroNoCoopSettlementServiceImpl.page(page, Wrappers.query(miroNoCoopSettlement)));
  }

  /**
   * 通过id查询${table.comment}
   * @param  id
   * @return XfR
   */
  @GetMapping("/mironocoopsettlements/{id}")
  public XfR getById(@PathVariable Long id) {
     return XfR.ok(miroNoCoopSettlementServiceImpl.getById(id));
  }

  /**
   * 新增${table.comment}
   * @param miroNoCoopSettlement ${table.comment}
   * @return XfR
   */
  @PostMapping("/mironocoopsettlements")
  public XfR save(@RequestBody MiroNoCoopSettlement miroNoCoopSettlement) {
     return XfR.ok(miroNoCoopSettlementServiceImpl.save(miroNoCoopSettlement));
  }

  /**
   * 修改-传入修改后的全部数据${table.comment}
   * @param miroNoCoopSettlement ${table.comment}
   * @return XfR
   */
  @PutMapping("/mironocoopsettlements/{id}")
  public XfR putUpdate(@RequestBody MiroNoCoopSettlement miroNoCoopSettlement,@PathVariable Long id) {
      miroNoCoopSettlement.setId(id);
      return XfR.ok(miroNoCoopSettlementServiceImpl.updateById(miroNoCoopSettlement));
  }

  /**
   * 修改-传入修改的数据${table.comment}
   * @param miroNoCoopSettlement ${table.comment}
   * @return XfR
   */
  @PatchMapping("/mironocoopsettlements/{id}")
  public XfR patchUpdate(@RequestBody MiroNoCoopSettlement miroNoCoopSettlement,@PathVariable Long id) {
      MiroNoCoopSettlement upmiroNoCoopSettlement = miroNoCoopSettlementServiceImpl.getById(id);
      if(upmiroNoCoopSettlement != null){
        upmiroNoCoopSettlement = ObjectCopyUtils.copyProperties(miroNoCoopSettlement,upmiroNoCoopSettlement,true);
      }
      return XfR.ok(miroNoCoopSettlementServiceImpl.updateById(upmiroNoCoopSettlement));
  }

  /**
   * 通过id删除${table.comment}
   * @param  id
   * @return XfR
   */
  @DeleteMapping("/mironocoopsettlements/{id}")
  public XfR removeById(@PathVariable Long id) {
     return XfR.ok(miroNoCoopSettlementServiceImpl.removeById(id));
  }

  @PostMapping("/mironocoopsettlements/query")
  public XfR querys(@RequestBody ConditionQueryRequest condition) {
     Map<String, Object> params = new HashMap();
     params.put("tableName", "miro_no_coop_settlement");
     params.put("request", condition);

     return XfR.ok(miroNoCoopSettlementServiceImpl.querys(params));
  }

}

==> compass-service-0.1.182-sources.jar: com/xforceplus/compass/controller/MiroNoCoopSettlementController.java <==
package com.xforceplus.compass.controller;


import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.GetMapping;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.xforceplus.ultraman.bocp.gen.plugins.XfPage;
import org.springframework.web.bind.annotation.*;
import org.springframework.beans.factory.annotation.Autowired;
import com.xforceplus.ultraman.bocp.gen.api.XfR;
import org.apache.commons.lang3.StringUtils;
import com.xforceplus.compass.entity.MiroNoCoopSettlement;
import com.xforceplus.compass.service.IMiroNoCoopSettlementService;
import lombok.AllArgsConstructor;
import com.xforceplus.ultraman.bocp.gen.util.ObjectCopyUtils;
import com.xforceplus.ultraman.bocp.gen.sql.pojo.ConditionQueryRequest;
import java.util.HashMap;
import java.util.Map;
import org.springframework.stereotype.Controller;

/**
 * ${table.comment}前端控制器
 *
 * @author ultraman
 * @date 2025-05-19
 */
@RestController
public class MiroNoCoopSettlementController {

  @Autowired
  private IMiroNoCoopSettlementService miroNoCoopSettlementServiceImpl;


  /**
   * 查询所有-分页模式
   * @param page 分页对象
   * @param miroNoCoopSettlement ${table.comment}
   * @return
   */
  @GetMapping("/mironocoopsettlements" )
  public XfR getMiroNoCoopSettlements(XfPage page, MiroNoCoopSettlement miroNoCoopSettlement) {
    return XfR.ok(miroNoCoopSettlementServiceImpl.page(page, Wrappers.query(miroNoCoopSettlement)));
  }

  /**
   * 通过id查询${table.comment}
   * @param  id
   * @return XfR
   */
  @GetMapping("/mironocoopsettlements/{id}")
  public XfR getById(@PathVariable Long id) {
     return XfR.ok(miroNoCoopSettlementServiceImpl.getById(id));
  }

  /**
   * 新增${table.comment}
   * @param miroNoCoopSettlement ${table.comment}
   * @return XfR
   */
  @PostMapping("/mironocoopsettlements")
  public XfR save(@RequestBody MiroNoCoopSettlement miroNoCoopSettlement) {
     return XfR.ok(miroNoCoopSettlementServiceImpl.save(miroNoCoopSettlement));
  }

  /**
   * 修改-传入修改后的全部数据${table.comment}
   * @param miroNoCoopSettlement ${table.comment}
   * @return XfR
   */
  @PutMapping("/mironocoopsettlements/{id}")
  public XfR putUpdate(@RequestBody MiroNoCoopSettlement miroNoCoopSettlement,@PathVariable Long id) {
      miroNoCoopSettlement.setId(id);
      return XfR.ok(miroNoCoopSettlementServiceImpl.updateById(miroNoCoopSettlement));
  }

  /**
   * 修改-传入修改的数据${table.comment}
   * @param miroNoCoopSettlement ${table.comment}
   * @return XfR
   */
  @PatchMapping("/mironocoopsettlements/{id}")
  public XfR patchUpdate(@RequestBody MiroNoCoopSettlement miroNoCoopSettlement,@PathVariable Long id) {
      MiroNoCoopSettlement upmiroNoCoopSettlement = miroNoCoopSettlementServiceImpl.getById(id);
      if(upmiroNoCoopSettlement != null){
        upmiroNoCoopSettlement = ObjectCopyUtils.copyProperties(miroNoCoopSettlement,upmiroNoCoopSettlement,true);
      }
      return XfR.ok(miroNoCoopSettlementServiceImpl.updateById(upmiroNoCoopSettlement));
  }

  /**
   * 通过id删除${table.comment}
   * @param  id
   * @return XfR
   */
  @DeleteMapping("/mironocoopsettlements/{id}")
  public XfR removeById(@PathVariable Long id) {
     return XfR.ok(miroNoCoopSettlementServiceImpl.removeById(id));
  }

  @PostMapping("/mironocoopsettlements/query")
  public XfR querys(@RequestBody ConditionQueryRequest condition) {
     Map<String, Object> params = new HashMap();
     params.put("tableName", "miro_no_coop_settlement");
     params.put("request", condition);

     return XfR.ok(miroNoCoopSettlementServiceImpl.querys(params));
  }

}
